@@ -31,6 +31,8 @@ pub struct RtcBuild {
     pub core: RtcCore,
     /// The index HTML file to drive the bundling process.
     pub target: PathBuf,
+    /// The name of the output HTML file.
+    pub html_output_filename: String,
     /// The parent directory of the target index HTML file.
     pub target_parent: PathBuf,
     /// Build in release mode.
@@ -54,6 +56,8 @@ pub struct RtcBuild {
     pub staging_dist: PathBuf,
     /// The configuration of the features passed to cargo.
     pub cargo_features: Features,
+    /// Optional example to be passed to cargo.
+    pub cargo_example: Option<String>,
     /// Configuration for automatic application download.
     pub tools: Tools,
     /// Build process hooks.
@@ -86,6 +90,8 @@ pub struct RtcBuild {
     pub no_sri: bool,
     /// Ignore error's due to self-closed script tags, instead will issue a warning.
     pub allow_self_closing_script: bool,
+    /// When set, create nonce attributes with the option as placeholder
+    pub create_nonce: Option<String>,
 }
 
 impl Deref for RtcBuild {
@@ -132,6 +138,15 @@ impl RtcBuild {
             )
         })?;
 
+        let html_output_filename = match build.html_output {
+            Some(html_output) => html_output,
+            None => target
+                .file_name()
+                .context("target path isn't a file path")?
+                .to_string_lossy()
+                .into_owned(),
+        };
+
         // Get the target HTML's parent dir, falling back to OS specific root, as that is the only
         // time when no parent could be determined.
         let target_parent = target
@@ -175,9 +190,12 @@ impl RtcBuild {
             public_url = public_url.fix_trailing_slash();
         }
 
+        let create_nonce = build.create_nonce.then_some(build.nonce_placeholder);
+
         Ok(Self {
             core,
             target,
+            html_output_filename,
             target_parent,
             release: build.release,
             cargo_profile: build.cargo_profile,
@@ -186,6 +204,7 @@ impl RtcBuild {
             staging_dist,
             final_dist,
             cargo_features,
+            cargo_example: build.example,
             tools,
             hooks,
             inject_autoloader,
@@ -203,6 +222,7 @@ impl RtcBuild {
             minify: build.minify,
             no_sri: build.no_sri,
             allow_self_closing_script: build.allow_self_closing_script,
+            create_nonce,
         })
     }
 
@@ -210,6 +230,7 @@ impl RtcBuild {
     #[cfg(test)]
     pub async fn new_test(tmpdir: &std::path::Path) -> anyhow::Result<Self> {
         let target = tmpdir.join("index.html");
+        let html_output_filename = String::from("index.html");
         let target_parent = tmpdir.to_path_buf();
         let final_dist = tmpdir.join("dist");
         let staging_dist = final_dist.join(".stage");
@@ -219,6 +240,7 @@ impl RtcBuild {
         Ok(Self {
             core: RtcCore::new_test(tmpdir),
             target,
+            html_output_filename,
             target_parent,
             release: false,
             cargo_profile: None,
@@ -227,6 +249,7 @@ impl RtcBuild {
             final_dist,
             staging_dist,
             cargo_features: Features::All,
+            cargo_example: None,
             tools: Default::default(),
             hooks: Vec::new(),
             inject_autoloader: true,
@@ -242,6 +265,7 @@ impl RtcBuild {
             minify: Minify::Never,
             no_sri: false,
             allow_self_closing_script: false,
+            create_nonce: None,
         })
     }
 
